function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import { Modal } from 'react-bootstrap';

/**
 * The modal dialog which can be altenative to `window.confirm` and `window.alert`.
 * @example <Dialog ref={(el) => {this.dialog = el} />
 * @example this.dialog.show({body: 'Hello!', actions: [Dialog.Action('do', () => console.log('ok'))]})
 * @example this.dialog.showAlert('Hello!')
 */

var Dialog = function (_React$Component) {
  _inherits(Dialog, _React$Component);

  /**
   * Set default options for applying to all dialogs.
   * @param options
   */
  Dialog.setOptions = function setOptions(options) {
    Dialog.options = Object.assign({}, Dialog.DEFAULT_OPTIONS, options);
  };

  /**
   * Reset default options to presets.
   */


  Dialog.resetOptions = function resetOptions() {
    Dialog.options = Dialog.DEFAULT_OPTIONS;
  };

  function Dialog(props) {
    _classCallCheck(this, Dialog);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _this.state = {
      showModal: false,
      actions: [],
      bsSize: undefined,
      onHide: null
    };
    _this.onHide = _this.onHide.bind(_this);
    return _this;
  }

  Dialog.prototype.componentWillUnmount = function componentWillUnmount() {
    if (this.state.showModal) {
      this.hide();
    }
  };

  /**
   * Show dialog with choices. This is similar to `window.confirm`.
   * @param options Object for dialog options.
   * @param options.title The title of dialog.
   * @param options.body The body of message.
   * @param options.actions {DialogAction} The choices for presenting to user.
   * @param options.bsSize {[null, 'medium', 'large', 'small']} The width size for dialog.
   * @param options.onHide {function} The method to call when the dialog was closed by clicking background.
   */


  Dialog.prototype.show = function show() {
    var _this2 = this;

    var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    var keyBinds = {};
    var actions = options.actions || [];
    actions.forEach(function (action) {
      if (action.key) {
        action.key.split(',').forEach(function (key) {
          keyBinds[key] = function () {
            action.func && action.func(_this2);
          };
        });
      }
    });
    // TODO: Add keybinds
    options['showModal'] = true;
    this.setState(options);
  };

  /**
   * Show message dialog This is similar to `window.alert`.
   * @param body The body of message.
   * @param bsSize {[null, 'medium', 'large', 'small']} The width size for dialog.
   */


  Dialog.prototype.showAlert = function showAlert(body) {
    var bsSize = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : undefined;

    var options = {
      body: body,
      actions: [Dialog.SingleOKAction()],
      bsSize: bsSize
    };
    this.show(options);
  };

  Dialog.prototype.onHide = function onHide() {
    var onHide = this.state.onHide;
    if (typeof onHide === 'function') {
      onHide(this);
    } else {
      this.hide();
    }
  };

  /**
   * Hide this dialog.
   */


  Dialog.prototype.hide = function hide() {
    if (!this.state.showModal) return;
    // TODO: Remove keybinds
    this.setState({ showModal: false });
  };

  Dialog.prototype.render = function render() {
    var _this3 = this;

    var size = typeof this.state.bsSize === 'undefined' ? 'small' : this.state.bsSize === 'medium' ? null : this.state.bsSize;
    return React.createElement(
      Modal,
      { show: this.state.showModal, onHide: this.onHide, bsSize: size },
      this.state.title && React.createElement(
        Modal.Header,
        { className: 'bg-primary' },
        React.createElement(
          Modal.Title,
          null,
          this.state.title
        )
      ),
      React.createElement(
        Modal.Body,
        null,
        typeof this.state.body === 'string' ? React.createElement(
          'p',
          null,
          this.state.body
        ) : this.state.body
      ),
      React.createElement(
        Modal.Footer,
        null,
        this.state.actions.map(function (action) {
          return React.createElement(
            'button',
            {
              key: action.label,
              type: 'button',
              className: 'btn btn-sm ' + action.className,
              onClick: function onClick() {
                action.func && action.func(_this3);
              },
              style: { minWidth: 82 } },
            action.label
          );
        })
      )
    );
  };

  return Dialog;
}(React.Component);

/**
 * The class to construct a choice for Dialog.
 * Use `Dialog.Action(options)`.
 */


export { Dialog as default };

var DialogAction = function () {
  /**
   * Constructor
   * @param label The text or node for button. Default is `OK`.
   * @param func The function to execute when button is clicked. Default is null.
   * @param className The class name for button. Default is ''.
   */
  function DialogAction(label, func, className, key) {
    _classCallCheck(this, DialogAction);

    this.label = label || Dialog.options.defaultOkLabel;
    this._func = func;
    this.className = className || 'btn-default';
    this.key = key;
  }

  DialogAction.prototype.func = function func(dialog) {
    // dialog.hide()
    this._func && this._func(dialog);
  };

  return DialogAction;
}();

Dialog.DEFAULT_OPTIONS = {
  defaultOkLabel: 'OK',
  defaultCancelLabel: 'Cancel',
  primaryClassName: 'btn-primary'
};

Dialog.options = Dialog.DEFAULT_OPTIONS;

Dialog.Action = function (label, func, className, key) {
  return new DialogAction(label, func, className, key);
};
Dialog.DefaultAction = function (label, func, className) {
  return new DialogAction(label, func, className && className.length > 0 ? className : Dialog.options.primaryClassName, 'enter');
};
Dialog.OKAction = function (func) {
  return new DialogAction(Dialog.options.defaultOkLabel, function (dialog) {
    dialog.hide();func && func(dialog);
  }, Dialog.options.primaryClassName, 'enter');
};
Dialog.CancelAction = function (func) {
  return new DialogAction(Dialog.options.defaultCancelLabel, function (dialog) {
    dialog.hide();func && func(dialog);
  }, null, 'esc');
};
Dialog.SingleOKAction = function () {
  return new DialogAction(Dialog.options.defaultOkLabel, function (dialog) {
    dialog.hide();
  }, Dialog.options.primaryClassName, 'enter,esc');
};

Dialog.displayName = 'Dialog';