import _regeneratorRuntime from 'babel-runtime/regenerator';

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import Picker from 'better-picker';
import _ from 'lodash';

var mapper = function mapper(category) {
  return { text: category.name, value: category.code, parent: category.parentCode };
};

var BrandFieldPicker = function () {
  function BrandFieldPicker(utilService, categoryStore) {
    var cbOk = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : _.noop;

    _classCallCheck(this, BrandFieldPicker);

    this.utilService = utilService;
    this.categoryStore = categoryStore;
    this.cbOk = cbOk;
  }

  BrandFieldPicker.prototype._loadBrands = function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      var brands;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              this.utilService.showSpinner('正在加载品牌数据，请稍候……');
              _context.next = 3;
              return this.categoryStore.getCategoriesWithChildren();

            case 3:
              this._source = _context.sent;
              brands = this._source.filter(function (category) {
                return category.parentCode === 'sbr';
              });

              this._brands = brands.map(mapper);
              this._loadSeries(this._brands[0].value);

            case 7:
            case 'end':
              return _context.stop();
          }
        }
      }, _callee, this);
    }));

    function _loadBrands() {
      return _ref.apply(this, arguments);
    }

    return _loadBrands;
  }();

  BrandFieldPicker.prototype._loadSeries = function _loadSeries(code) {
    var series = this._source.filter(function (category) {
      return category.parentCode === code;
    });
    this._series = series.map(mapper);
  };

  BrandFieldPicker.prototype._showPicker = function _showPicker() {
    if (this._picker) return this._picker.show();
    var picker = new Picker({
      data: [this._brands, this._series],
      selectedIndex: [0, 0],
      title: '请选择品牌系列'
    });
    picker.on('picker.change', this._handlePickerChange.bind(this));
    picker.on('picker.select', this._handlePickerSelect.bind(this));
    picker.show();
    this._picker = picker;
  };

  BrandFieldPicker.prototype._handlePickerChange = function _handlePickerChange(index, selectIndex) {
    if (index !== 0) return;
    this._loadSeries(this._brands[selectIndex].value);
    this._picker.refillColumn(1, this._series);
  };

  BrandFieldPicker.prototype._handlePickerSelect = function _handlePickerSelect(selectedVal, selectedIndex) {
    var selectedBrand = this._transfer(this._brands[selectedIndex[0]]);
    var selectedSerie = this._transfer(this._series[selectedIndex[1]]);
    // 如果还没滚动完成就点击“确定”，就有可能还没有执行 change 事件，所以需要手动执行。
    if (!selectedSerie || selectedSerie.parentCode !== selectedBrand.code) {
      this._handlePickerChange(0, selectedIndex[0]);
      selectedSerie = this._transfer(this._series[0]);
    }
    this.cbOk({
      brand: selectedBrand,
      serie: selectedSerie
    });
  };

  BrandFieldPicker.prototype._transfer = function _transfer(from) {
    if (!from) return from;
    return {
      name: from.text,
      code: from.value,
      parentCode: from.parent
    };
  };

  BrandFieldPicker.prototype.showPicker = function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
      return _regeneratorRuntime.wrap(function _callee2$(_context2) {
        while (1) {
          switch (_context2.prev = _context2.next) {
            case 0:
              if (!this._source) {
                _context2.next = 2;
                break;
              }

              return _context2.abrupt('return', this._showPicker());

            case 2:
              _context2.next = 4;
              return this._loadBrands();

            case 4:
              this._showPicker();

            case 5:
            case 'end':
              return _context2.stop();
          }
        }
      }, _callee2, this);
    }));

    function showPicker() {
      return _ref2.apply(this, arguments);
    }

    return showPicker;
  }();

  return BrandFieldPicker;
}();

export { BrandFieldPicker as default };