var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

import React from 'react';
import { Label } from 'react-bootstrap';
import moment from 'moment';

import { Validators } from 'fashionipo-services/es/utility';

import './Pipe.scss';

var EVAL_RESULT = {
  real: '鉴定为真',
  fake: '鉴定为假',
  impossible: '无法鉴定',
  insufficient: '需要补图'
};

var Pipe = function () {
  function Pipe(value) {
    _classCallCheck(this, Pipe);

    this._value = value;
  }

  Pipe.prototype.protect = function protect() {
    if (Validators.isIdCard(this._value)) {
      this._value = this._value.replace(/.{4}$/, '****');
      return this;
    }
    if (Validators.isMobile(this._value)) {
      this._value = this._value.replace(/(\d{3})\d{4}(\d{4})/, '$1****$2');
      return this;
    }
    return this;
  };

  Pipe.prototype.evalResult = function evalResult() {
    this._value = EVAL_RESULT[this._value];
    return this;
  };

  Pipe.prototype.canViewResult = function canViewResult() {
    if (this._value === true) {
      this._value = React.createElement(
        Label,
        { bsStyle: 'success' },
        '\u5DF2\u4E0A\u67B6'
      );
    }
    if (this._value === false) {
      this._value = React.createElement(
        Label,
        { bsStyle: 'danger' },
        '\u672A\u4E0A\u67B6'
      );
    }
    return this;
  };

  Pipe.prototype.canTradeResult = function canTradeResult() {
    if (this._value === true) {
      this._value = React.createElement(
        Label,
        { bsStyle: 'success' },
        '\u53EF\u4EA4\u6613'
      );
    }
    if (this._value === false) {
      this._value = React.createElement(
        Label,
        { bsStyle: 'danger' },
        '\u4E0D\u53EF\u4EA4\u6613'
      );
    }
    return this;
  };

  Pipe.prototype.priceChangePercent = function priceChangePercent() {
    var change = this._value;
    if (change.priceChangePercentage === undefined) {
      this._value = null;
      return this;
    }
    this._value = React.createElement(
      'span',
      { className: change.priceChangePercentagePositive ? 'positive' : 'negative' },
      change.priceChangePercentagePositive ? React.createElement('i', { className: 'fa fa-long-arrow-up' }) : React.createElement('i', { className: 'fa fa-long-arrow-down' }),
      change.priceChangePercentage,
      '%'
    );
    return this;
  };

  Pipe.prototype.expired = function expired() {
    var compareDate = moment(this._value);
    var left = compareDate.diff(Date.now(), 'days') + 1;
    var message = moment().isBefore(compareDate) && left > 0 ? '\u8FD8\u5269 ' + left + ' \u5929' : '已过期';
    this._value = React.createElement(
      'span',
      { className: left <= 1 ? 'app-watchout' : '' },
      message
    );
    return this;
  };

  _createClass(Pipe, [{
    key: 'value',
    get: function get() {
      return this._value;
    }
  }, {
    key: 'v',
    get: function get() {
      return this._value;
    }
  }]);

  return Pipe;
}();

export default function P(value) {
  return new Pipe(value);
}